@@ -132,7 +132,7 @@ class MediaRelated(MediaResource):
         if self.url:
             url_types = ['.png', '.jpg', '.gif', '.jpeg']
             for type in url_types:
-                if type in self.url:
+                if type in self.url or type.upper() in self.url:
                     is_url_image = True
         return 'image' in self.mime_type or is_url_image
 
@@ -675,3 +675,33 @@ class MediaFondsRelated(MediaRelated):
         verbose_name = _('fonds related media')
         verbose_name_plural = _('fonds related media')
 
+
+class Format(ModelCore):
+    """ Physical format object as proposed by the LAM"""
+
+    item = ForeignKey(MediaItem, related_name="formats", verbose_name=_('item'))
+    original_code = CharField(_('original code'), required=True)
+    tape_number = CharField(_('tape number'))
+    status = CharField(_('status'))
+    conservation_state = CharField(_('conservation state'))
+    comments = TextField(_('comments'))
+
+    tape_length = WeakForeignKey(TapeLength, related_name="formats", verbose_name = _("tape length (cm)"))
+    tape_width  = WeakForeignKey(TapeWidth, related_name="formats", verbose_name = _("tape width (inch)"))
+    tape_speed = WeakForeignKey(TapeSpeed, related_name="formats", verbose_name = _("tape speed (m/s)"))
+    tape_vendor = WeakForeignKey(TapeVendor, related_name="formats")
+    tape_thickness = CharField(_('tape thickness (um)'))
+    tape_diameter = CharField(_('tape diameter (mm)'))
+    tape_reference = CharField(_('tape reference'))
+
+    class Meta(MetaCore):
+        db_table = 'media_formats'
+        verbose_name = _('format')
+
+    def __unicode__(self):
+        return self.original_code
+
+    @property
+    def public_id(self):
+        return self.original_code
+
