@@ -15,6 +15,7 @@ import re
 import os
 import datetime
 from django.conf import settings
+from django.template.defaultfilters import stringfilter
 
 register = template.Library()
 
@@ -24,12 +25,12 @@ def tolist(dict):
     list = []
     for k, v in dict.iteritems():
         list.append({'name': k, 'value': v})
-    return list        
+    return list
 
 @register.filter
 def mul(value, arg):
     "Multiply a numeric value"
-    return value * arg        
+    return value * arg
 
 class TelemetaVersionNode(template.Node):
     def render(self, context):
@@ -70,6 +71,13 @@ def escapejs(value):
         value = value.replace(bad, good)
     return value
 
+@register.filter
+def build_pattern_string(criteria):
+    dict = {}
+    for c in criteria:
+        dict[c.key] = c.value
+    return dict
+
 @register.filter
 def build_query_string(vars):
     """Build an HTTP query string out of a dict"""
@@ -108,7 +116,7 @@ def code_or_id(resource):
         return resource.code
     else:
         return resource.id
-     
+
 @register.filter
 def is_item(resource):
     return isinstance(resource, models.MediaItem)
@@ -117,12 +125,26 @@ def is_item(resource):
 def is_collection(resource):
     return isinstance(resource, models.MediaCollection)
 
+@register.filter
+def is_corpus(resource):
+    return isinstance(resource, models.MediaCorpus)
+
+@register.filter
+def is_fonds(resource):
+    return isinstance(resource, models.MediaFonds)
+
+@register.filter
+def is_resource(resource):
+    return is_fonds(resource) or is_corpus(resource)
+
 @register.filter
 def to_dublincore(resource):
     if isinstance(resource, models.MediaItem):
         return dc.express_item(resource)
-    else:
+    elif isinstance(resource, models.MediaCollection):
         return dc.express_collection(resource)
+    else:
+        return dc.express_generic_resource(resource)
 
 class DescriptionListFieldNode(template.Node):
     def __init__(self, model, attr, join_with = None, show_empty = False):
@@ -186,8 +208,8 @@ def dl_field(parser, token):
                 show_empty = True
             else:
                 raise ValueError();
-    else:                
-        raise template.TemplateSyntaxError("%r tag: invalid arguments" 
+    else:
+        raise template.TemplateSyntaxError("%r tag: invalid arguments"
                                            % token.contents.split()[0])
 
     if attr[0] == attr[-1] and attr[0] in ('"', "'"):
@@ -207,7 +229,7 @@ def prepend(str, prefix):
 def field_label(model, field=None):
     if isinstance(model, basestring):
         model = getattr(models, model)
-            
+
     if not field:
         return capfirst(unicode(model._meta.verbose_name))
 
@@ -239,7 +261,7 @@ def resources_num(value):
             'count': count, }
 
     return label
-    
+
 @register.filter
 def split(value, sep=','):
     return value.split(sep)
@@ -295,11 +317,11 @@ def description():
     return description
 
 class SetVarNode(template.Node):
- 
+
     def __init__(self, var_name, var_value):
         self.var_name = var_name
         self.var_value = var_value
- 
+
     def render(self, context):
         try:
             value = template.Variable(self.var_value).resolve(context)
@@ -308,7 +330,7 @@ class SetVarNode(template.Node):
         context[self.var_name] = value
         return u""
 
-@register.tag 
+@register.tag
 def set_var(parser, token):
     """
         {% set <var_name>  = <var_value> %}
@@ -317,7 +339,7 @@ def set_var(parser, token):
     if len(parts) < 4:
         raise template.TemplateSyntaxError("'set' tag must be of the form:  {% set <var_name>  = <var_value> %}")
     return SetVarNode(parts[1], parts[3])
- 
+
 @register.simple_tag
 def current_year():
     return datetime.datetime.now().strftime("%Y")
@@ -347,8 +369,31 @@ def get_filename(object):
 @register.filter
 def get_youtube(link):
     link = link.split('&')
-    if "=" in link:
+    if "=" in link[0]:
         ref = link[0].split('=')[1]
     else:
         ref = link[0].split('/')[-1]
     return 'http://www.youtube.com/embed/'+ref
+
+@register.filter
+def to_utf8(word):
+    return word.encode('utf-8')
+
+@register.filter
+@stringfilter
+def capitalize(value):
+    return value.capitalize()
+
+@register.filter
+@stringfilter
+def mime_to_ext(mime_type):
+    return mime_type.split('/')[1]
+
+@register.filter
+@stringfilter
+def mime_to_media_type(mime_type):
+    if 'video' in mime_type:
+        return 'Video'
+    else:
+        return 'Audio'
+
